@@ -1,7 +1,8 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
-from .loader import AdvisoriesLoader
 from .json import JSONAdvisoriesLoader
+from .loader import AdvisoriesLoader
+
+__all__ = ("JSONAdvisoriesLoader", "AdvisoriesLoader")
