@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
@@ -44,10 +43,10 @@ class VerifierTestCase(unittest.TestCase):
         """
         returns not_in_result and in result
         """
-        greater = lambda: name.replace(  # pylint: disable=unnecessary-lambda-assignment
+        greater = lambda: name.replace(  # pylint: disable=unnecessary-lambda-assignment  # noqa: E731
             "15", "16"
         )
-        smaller = lambda: name.replace(  # pylint: disable=unnecessary-lambda-assignment
+        smaller = lambda: name.replace(  # pylint: disable=unnecessary-lambda-assignment  # noqa: E731
             "15", "14"
         )  # pylint: disable=unnecessary-lambda-assignment
         if not verifier:
